@@ -1,4 +1,5 @@
 import os
+import sys
 from collections import defaultdict
 from copy import deepcopy
 from math import ceil
@@ -89,7 +90,7 @@ DEFAULT_LOG_LINEAR_X_AXIS_BASE = 1.1
 
 
 def report(msg):
-    print("%s: %s" % (ctime(time()), msg))
+    print("%s: %s" % (ctime(time()), msg), file=sys.stderr)
 
 
 def alignmentGraph(
