@@ -3,35 +3,18 @@ from __future__ import annotations
 import argparse
 import itertools
 import os
-import sys
 from collections import Counter, defaultdict
-from collections.abc import Sized
+from collections.abc import Iterable, Iterator, Sequence, Sized
 from functools import total_ordering
 from hashlib import md5
 from pathlib import Path
 from random import uniform
-from typing import (
-    Callable,
-    Dict,
-    Generator,
-    Iterable,
-    List,
-    Literal,
-    Optional,
-    Sequence,
-    Set,
-    SupportsIndex,
-    TextIO,
-    Tuple,
-    Union,
-)
+from typing import Callable, Literal, SupportsIndex
 
-from Bio.Data.IUPACData import (
-    ambiguous_dna_complement,  # type: ignore
-    ambiguous_rna_complement,  # type: ignore
-)
-from Bio.Seq import translate  # type: ignore
+from Bio.Data.IUPACData import ambiguous_dna_complement, ambiguous_rna_complement
+from Bio.Seq import translate  # pyright: ignore[reportUnknownVariableType]
 
+from dark import File
 from dark.aaVars import (
     AA_LETTERS,
     NONE,
@@ -46,7 +29,7 @@ from dark.filter import SequenceFilter, TitleFilter
 from dark.hsp import HSP
 
 
-def _makeComplementTable(complementData: dict) -> Sequence[str]:
+def _makeComplementTable(complementData: dict[str, str]) -> Sequence[str]:
     """
     Make a sequence complement table.
 
@@ -77,18 +60,18 @@ class Read(Sized):
         match the length of the sequence.
     """
 
-    ALPHABET: Optional[set] = None
+    ALPHABET: set[str] = set()
 
-    def __init__(self, id: str, sequence: str, quality: Optional[str] = None):
+    def __init__(self, id: str, sequence: str, quality: str | None = None):
         if quality is not None and len(quality) != len(sequence):
             raise ValueError(
-                "Invalid read: sequence length (%d) != quality length (%d)"
-                % (len(sequence), len(quality))
+                f"Invalid read: sequence length ({len(sequence)}) "
+                f"!= quality length ({len(quality)})"
             )
 
-        self.id = id
-        self.sequence = sequence
-        self.quality = quality
+        self.id: str = id
+        self.sequence: str = sequence
+        self.quality: str | None = quality
 
     def __eq__(self, other: object) -> bool:
         if isinstance(other, Read):
@@ -142,7 +125,7 @@ class Read(Sized):
                 ).digest()
             )
 
-    def __getitem__(self, item: Union[int, slice]) -> Read:
+    def __getitem__(self, item: int | slice) -> Read:
         sequence = self.sequence[item]
         quality = None if self.quality is None else self.quality[item]
         return self.__class__(self.id, sequence, quality)
@@ -158,21 +141,16 @@ class Read(Sized):
         @return: A C{str} representing the read in the requested format.
         """
         if format_ == "fasta":
-            return ">%s\n%s\n" % (self.id, self.sequence)
+            return f">{self.id}\n{self.sequence}\n"
         elif format_ == "fastq":
             if self.quality is None:
-                raise ValueError("Read %r has no quality information" % self.id)
+                raise ValueError(f"Read {self.id!r} has no quality information")
             else:
-                return "@%s\n%s\n+%s\n%s\n" % (
-                    self.id,
-                    self.sequence,
-                    self.id,
-                    self.quality,
-                )
+                return f"@{self.id}\n{self.sequence}\n+{self.id}\n{self.quality}\n"
         else:
             raise ValueError("Format must be either 'fasta', 'fastq' or 'fasta-ss'.")
 
-    def toDict(self) -> dict:
+    def toDict(self) -> dict[str, str | None]:
         """
         Get information about this read in a dictionary.
 
@@ -229,7 +207,7 @@ class Read(Sized):
             return self.__class__(self.id, newSequence, newQuality)
 
     @classmethod
-    def fromDict(cls, d: dict) -> Read:
+    def fromDict(cls, d: dict[str, str]) -> Read:
         """
         Create a new instance from attribute values provided in a dictionary.
 
@@ -258,7 +236,7 @@ class Read(Sized):
 
     def walkHSP(
         self, hsp: HSP, includeWhiskers: bool = True
-    ) -> Generator[Tuple[int, str, bool], None, None]:
+    ) -> Iterator[tuple[int, str, bool]]:
         """
         Provide information about exactly how a read matches a subject, as
         specified by C{hsp}.
@@ -303,7 +281,7 @@ class Read(Sized):
                 readOffset += 1
                 subjectOffset += 1
 
-    def checkAlphabet(self, count: int = 10) -> set:
+    def checkAlphabet(self, count: int | None = 10) -> set[str]:
         """
         A function which checks whether the sequence in a L{dark.Read} object
         corresponds to its readClass. For AA reads, more testing is done in
@@ -322,33 +300,25 @@ class Read(Sized):
             readLetters = set(self.sequence.upper())
         else:
             readLetters = set(self.sequence.upper()[:count])
-        # Check if readLetters is a subset of self.ALPHABET.
-        if self.ALPHABET is None or readLetters.issubset(self.ALPHABET):
+        # Check if readLetters is a subset of self.ALPHABET (if we have one).
+        if readLetters.issubset(self.ALPHABET) or not self.ALPHABET:
             return readLetters
         raise ValueError(
-            "Read alphabet (%r) is not a subset of expected "
-            "alphabet (%r) for read class %s."
-            % (
-                "".join(sorted(readLetters)),
-                "".join(sorted(self.ALPHABET)),
-                str(self.__class__.__name__),
-            )
+            f"Read alphabet ({''.join(sorted(readLetters))!r}) is not a subset of "
+            f"expected alphabet ({''.join(sorted(self.ALPHABET))!r}) for read class "
+            f"{str(self.__class__.__name__)}."
         )
 
-    def newFromSites(self, sites: Set[int], exclude: bool = False) -> Read:
+    def newFromSites(self, sites: set[int], exclude: bool = False) -> Read:
         """
         Create a new read from self, with only certain sites.
 
         @param sites: A set of C{int} 0-based sites (i.e., indices) in
-            sequences that should be kept. If C{None} (the default), all sites
-            are kept.
+            sequences that should be kept.
         @param exclude: If C{True} the C{sites} will be excluded, not
             included.
         @return: A new C{Read} instance.
         """
-        if sites is None:
-            sites = set(range(len(self)))
-
         if exclude:
             sites = set(range(len(self))) - sites
 
@@ -467,11 +437,11 @@ class _NucleotideRead(Read):
     Holds methods to work with nucleotide (DNA and RNA) sequences.
     """
 
-    COMPLEMENT_TABLE: Sequence[Union[str, None]] = [None]
+    COMPLEMENT_TABLE: Sequence[str | None] = [None]
 
     def translations(
-        self: Union[_NucleotideRead, DNARead, RNARead],
-    ) -> Generator[TranslatedRead, None, None]:
+        self: _NucleotideRead | DNARead | RNARead,
+    ) -> Iterator[TranslatedRead]:
         """
         Yield all six translations of a nucleotide sequence.
 
@@ -494,7 +464,7 @@ class _NucleotideRead(Read):
                     self, translate(suffix), frame, reverseComplemented
                 )
 
-    def reverseComplement(self: Union[_NucleotideRead, DNARead, RNARead]) -> Read:
+    def reverseComplement(self: _NucleotideRead | DNARead | RNARead) -> Read:
         """
         Reverse complement a nucleotide sequence.
 
@@ -511,7 +481,7 @@ class DNARead(_NucleotideRead):
     Hold information and methods to work with DNA reads.
     """
 
-    ALPHABET: set = set("ATCG")
+    ALPHABET: set[str] = set("ATCG")
 
     COMPLEMENT_TABLE = _makeComplementTable(ambiguous_dna_complement)
 
@@ -521,8 +491,8 @@ class DNARead(_NucleotideRead):
         forward: bool = True,
         requireStartCodon: bool = True,
         allowGaps: bool = True,
-        untranslatable: Optional[Dict[str, str]] = None,
-    ):
+        untranslatable: dict[str, str] | None = None,
+    ) -> dict[str, int | bool | str]:
         """
         Find an ORF that supposedly starts at a specified offset in a read.
 
@@ -629,18 +599,17 @@ class DNAKozakRead(DNARead):
 
     def __init__(self, originalRead: Read, start: int, stop: int, kozakQuality: float):
         if start < 0:
-            raise ValueError("start offset (%d) less than zero" % start)
+            raise ValueError(f"start offset ({start}) less than zero")
         if stop > len(originalRead):
             raise ValueError(
-                "stop offset (%d) > original read length (%d)"
-                % (stop, len(originalRead))
+                f"stop offset ({stop}) > original read length ({len(originalRead)})"
             )
         if start > stop:
             raise ValueError(
-                "start offset (%d) greater than stop offset (%d)" % (start, stop)
+                f"start offset ({start}) greater than stop offset ({stop})"
             )
 
-        newId = "%s-(%d:%d)" % (originalRead.id, start, stop)
+        newId = f"{originalRead.id}-({start}:{stop})"
 
         if originalRead.quality:
             DNARead.__init__(
@@ -700,7 +669,7 @@ class AARead(Read):
             )
         return readLetters
 
-    def properties(self) -> Generator[int, None, None]:
+    def properties(self) -> Iterator[int]:
         """
         Translate an amino acid sequence to properties of the form:
         'F': HYDROPHOBIC | AROMATIC.
@@ -710,16 +679,16 @@ class AARead(Read):
         """
         return (PROPERTIES.get(aa, NONE) for aa in self.sequence)
 
-    def propertyDetails(self) -> Generator[Union[dict, int], None, None]:
+    def propertyDetails(self) -> Iterator[dict | int]:
         """
         Translate an amino acid sequence to properties. Each property of the
         amino acid gets a value scaled from -1 to 1.
 
-        @return: A generator yielding property dictionaries.
+        @return: An interator yielding property dictionaries.
         """
         return (PROPERTY_DETAILS.get(aa, NONE) for aa in self.sequence)
 
-    def ORFs(self, openORFs: bool = False) -> Generator[AAReadORF, None, None]:
+    def ORFs(self, openORFs: bool = False) -> Iterator[AAReadORF]:
         """
         Find all ORFs in our sequence.
 
@@ -813,22 +782,18 @@ class AAReadORF(AARead):
         openRight: bool,
     ):
         if start < 0:
-            raise ValueError("start offset (%d) less than zero" % start)
+            raise ValueError(f"start offset ({start}) less than zero")
         if stop > len(originalRead):
             raise ValueError(
-                "stop offset (%d) > original read length (%d)"
-                % (stop, len(originalRead))
+                f"stop offset ({stop}) > original read length ({len(originalRead)})"
             )
         if start > stop:
             raise ValueError(
-                "start offset (%d) greater than stop offset (%d)" % (start, stop)
+                f"start offset ({start}) greater than stop offset ({stop})"
             )
-        newId = "%s-%s%d:%d%s" % (
-            originalRead.id,
-            "(" if openLeft else "[",
-            start,
-            stop,
-            ")" if openRight else "]",
+        newId = (
+            f"{originalRead.id}-{'(' if openLeft else '['}"
+            f"{start}:{stop}{')' if openRight else ']'}"
         )
         if originalRead.quality:
             AARead.__init__(
@@ -901,14 +866,14 @@ class SSAARead(AARead):
     @raise ValueError: If the sequence and structure lengths are not the same.
     """
 
-    def __init__(self, id, sequence: str, structure: str):
+    def __init__(self, id: str, sequence: str, structure: str):
         super().__init__(id, sequence)
-        self.structure = structure
+        self.structure: str = structure
 
         if len(sequence) != len(structure):
             raise ValueError(
-                "Invalid read: sequence length (%d) != structure length (%d)"
-                % (len(sequence), len(structure))
+                f"Invalid read: sequence length ({len(sequence)}) "
+                f"!= structure length ({len(structure)})"
             )
 
     def __eq__(self, other: object) -> bool:
@@ -937,7 +902,7 @@ class SSAARead(AARead):
             ).digest()
         )
 
-    def __getitem__(self, item: Union[int, slice]) -> SSAARead:
+    def __getitem__(self, item: int | slice) -> SSAARead:
         sequence = self.sequence[item]
         structure = self.structure[item] if self.structure else ""
         return self.__class__(self.id, sequence, structure)
@@ -960,17 +925,14 @@ class SSAARead(AARead):
             FASTA format.
         """
         if format_ == "fasta-ss":
-            return ">%s\n%s\n>%s%s\n%s\n" % (
-                self.id,
-                self.sequence,
-                self.id,
-                structureSuffix,
-                self.structure,
+            return (
+                f">{self.id}\n{self.sequence}\n"
+                f">{self.id}{structureSuffix}\n{self.structure}\n"
             )
         else:
             return super().toString(format_=format_)
 
-    def toDict(self):
+    def toDict(self) -> dict[str, str]:
         """
         Get information about this read in a dictionary.
 
@@ -983,7 +945,7 @@ class SSAARead(AARead):
         }
 
     @classmethod
-    def fromDict(cls, d):
+    def fromDict(cls, d: dict[str, str]):
         """
         Create a new instance from attribute values provided in a dictionary.
 
@@ -994,7 +956,7 @@ class SSAARead(AARead):
         """
         return cls(d["id"], d["sequence"], d["structure"])
 
-    def newFromSites(self, sites, exclude=False):
+    def newFromSites(self, sites: set[int], exclude: bool = False):
         """
         Create a new read from self, with only certain sites.
 
@@ -1042,11 +1004,7 @@ class TranslatedRead(AARead):
     def __init__(self, originalRead, sequence, frame, reverseComplemented=False):
         if frame not in (0, 1, 2):
             raise ValueError("Frame must be 0, 1, or 2")
-        newId = "%s-frame%d%s" % (
-            originalRead.id,
-            frame,
-            "rc" if reverseComplemented else "",
-        )
+        newId = f"{originalRead.id}-frame{frame}{'rc' if reverseComplemented else ''}"
         AARead.__init__(self, newId, sequence)
         self.frame = frame
         self.reverseComplemented = reverseComplemented
@@ -1248,47 +1206,47 @@ class ReadFilter:
 
     def __init__(
         self,
-        minLength: Optional[int] = None,
-        maxLength: Optional[int] = None,
-        maxNFraction: Optional[float] = None,
+        minLength: int | None = None,
+        maxLength: int | None = None,
+        maxNFraction: float | None = None,
         removeGaps: bool = False,
-        whitelist: Optional[set[str]] = None,
-        blacklist: Optional[set[str]] = None,
-        whitelistFile: Optional[str] = None,
-        blacklistFile: Optional[str] = None,
-        titleRegex: Optional[str] = None,
-        negativeTitleRegex: Optional[str] = None,
-        truncateTitlesAfter: Optional[str] = None,
-        sequenceWhitelist: Optional[set[str]] = None,
-        sequenceBlacklist: Optional[set[str]] = None,
-        sequenceWhitelistFile: Optional[str] = None,
-        sequenceBlacklistFile: Optional[str] = None,
-        sequenceRegex: Optional[str] = None,
-        sequenceNegativeRegex: Optional[str] = None,
-        keepSequences: Optional[set[int]] = None,
-        removeSequences: Optional[set[int]] = None,
-        head: Optional[int] = None,
+        whitelist: set[str] | None = None,
+        blacklist: set[str] | None = None,
+        whitelistFile: str | None = None,
+        blacklistFile: str | None = None,
+        titleRegex: str | None = None,
+        negativeTitleRegex: str | None = None,
+        truncateTitlesAfter: str | None = None,
+        sequenceWhitelist: set[str] | None = None,
+        sequenceBlacklist: set[str] | None = None,
+        sequenceWhitelistFile: str | None = None,
+        sequenceBlacklistFile: str | None = None,
+        sequenceRegex: str | None = None,
+        sequenceNegativeRegex: str | None = None,
+        keepSequences: set[int] | None = None,
+        removeSequences: set[int] | None = None,
+        head: int | None = None,
         removeDuplicates: bool = False,
         removeDuplicatesById: bool = False,
         removeDuplicatesUseMD5: bool = False,
         removeDescriptions: bool = False,
-        modifier: Optional[Callable[[Read], Union[Read, None]]] = None,
-        randomSubset: Optional[int] = None,
-        trueLength: Optional[int] = None,
-        sampleFraction: Optional[float] = None,
-        sequenceNumbersFile: Optional[str] = None,
-        idLambda: Optional[str] = None,
-        readLambda: Optional[str] = None,
-        keepSites: Optional[set[int]] = None,
-        removeSites: Optional[set[int]] = None,
+        modifier: Callable[[Read], Read | None] | None = None,
+        randomSubset: int | None = None,
+        trueLength: int | None = None,
+        sampleFraction: float | None = None,
+        sequenceNumbersFile: str | None = None,
+        idLambda: str | None = None,
+        readLambda: str | None = None,
+        keepSites: set[int] | None = None,
+        removeSites: set[int] | None = None,
         reverse: bool = False,
         reverseComplement: bool = False,
         upper: bool = False,
         lower: bool = False,
         upperId: bool = False,
         lowerId: bool = False,
-        rotate: Optional[int] = None,
-    ):
+        rotate: int | None = None,
+    ) -> None:
         if randomSubset is not None:
             if sampleFraction is not None:
                 raise ValueError(
@@ -1354,8 +1312,8 @@ class ReadFilter:
         self.yieldCount = 0
         self.readIndex = -1
 
-        self.titleFilter: Optional[TitleFilter] = None
-        self.sequenceFilter: Optional[SequenceFilter] = None
+        self.titleFilter: TitleFilter | None = None
+        self.sequenceFilter: SequenceFilter | None = None
 
         def _wantedSequences(filename):
             """
@@ -1372,8 +1330,8 @@ class ReadFilter:
                     if lastNumber is None:
                         if n < 1:
                             raise ValueError(
-                                "First line of sequence number file %r must "
-                                "be at least 1." % filename
+                                f"First line of sequence number file {filename!r} must "
+                                "be at least 1."
                             )
                         lastNumber = n
                         yield n
@@ -1383,8 +1341,8 @@ class ReadFilter:
                             yield n
                         else:
                             raise ValueError(
-                                "Line number file %r contains non-ascending "
-                                "numbers %d and %d." % (filename, lastNumber, n)
+                                f"Line number file {filename!r} contains non-ascending "
+                                f"numbers {lastNumber} and {n}."
                             )
 
         self.wantedSequenceNumberGeneratorExhausted = False
@@ -1453,7 +1411,7 @@ class ReadFilter:
         self.idLambda = eval(idLambda) if idLambda else None
         self.readLambda = eval(readLambda) if readLambda else None
 
-    def filter(self, read):
+    def filter(self, read: Read) -> Read | Literal[False]:
         """
         Check if a read passes the filter.
 
@@ -1667,13 +1625,13 @@ class Reads:
         subclass) instances.
     """
 
-    def __init__(self, initialReads: Optional[Iterable[Read]] = None) -> None:
-        self._initialReads = initialReads
-        self._additionalReads: List[Read] = []
-        self._filters: List[Callable] = []
-        self._iterated = False
+    def __init__(self, initialReads: Iterable[Read] | None = None) -> None:
+        self._initialReads: Iterable[Read] | None = initialReads
+        self._additionalReads: list[Read] = []
+        self._filters: list[Callable[[Read], Read | Literal[False]]] = []
+        self._iterated: bool = False
 
-    def filterRead(self, read: Read) -> Union[Literal[False], Read]:
+    def filterRead(self, read: Read) -> Literal[False] | Read:
         """
         Filter a read, according to our set of filters.
 
@@ -1697,7 +1655,7 @@ class Reads:
         """
         self._additionalReads.append(read)
 
-    def __iter__(self) -> Generator[Read, None, None]:
+    def __iter__(self) -> Iterator[Read]:
         """
         Iterate through all the reads.
 
@@ -1765,7 +1723,7 @@ class Reads:
                 "it has been iterated."
             )
 
-    def iter(self) -> Union[Generator[Read, None, None], list]:
+    def iter(self) -> Iterator[Read]:
         """
         Placeholder to allow subclasses to provide reads.
 
@@ -1777,9 +1735,7 @@ class Reads:
         """
         return []
 
-    def save(
-        self, filename: Union[str, TextIO], format_: str = "fasta", mode: str = "w"
-    ) -> int:
+    def save(self, filename: File, format_: str = "fasta", mode: str = "w") -> int:
         """
         Write the reads to C{filename} in the requested format.
 
@@ -1832,7 +1788,7 @@ class Reads:
         self._filters = []
         return self
 
-    def summarizePosition(self, index: int) -> dict:
+    def summarizePosition(self, index: int) -> dict[str, int | Counter[str]]:
         """
         Compute residue counts at a specific sequence index.
 
@@ -1840,7 +1796,7 @@ class Reads:
         @return: A C{dict} with the count of the reads, the too-short (excluded)
             sequences, and a Counter instance giving the base/residue counts.
         """
-        countAtPosition: Counter = Counter()
+        countAtPosition: Counter[str] = Counter()
         excludedCount = readCount = 0
 
         for read in iter(self):
@@ -1856,7 +1812,7 @@ class Reads:
             "readCount": readCount,
         }
 
-    def sitesMatching(self, targets: set, matchCase: bool, any_: bool) -> set[int]:
+    def sitesMatching(self, targets: set[str], matchCase: bool, any_: bool) -> set[int]:
         """
         Find sites (i.e., sequence indices) that match a given set of target
         sequence bases.
@@ -1875,8 +1831,7 @@ class Reads:
             targets = set(map(str.lower, targets))
 
         # result = set() if any_ else None
-        if any_:
-            result: set[int] = set()
+        result: set[int] = set()
 
         # I am using a 'first' variable here instead of just setting
         # 'result' to be None and testing that below, because if I let it
@@ -1902,7 +1857,7 @@ class Reads:
 
         # Make sure we don't return None.
         # return result or set()
-        return set() if result is None else result
+        return result
 
     def variableSites(
         self,
@@ -1969,14 +1924,14 @@ class Reads:
             ):
                 sequence += list(bases.intersection({"A", "T", "G", "C"}))[0]
             else:
-                nucleotides = set()
+                nucleotides: set[str] = set()
                 for base in bases:
                     nucleotides.update(AMBIGUOUS.get(base, set()))
                 try:
                     sequence += BASES_TO_AMBIGUOUS["".join(sorted(nucleotides))]
                 except KeyError:
                     raise ValueError(
-                        "Unknown DNA base(s): %r" % (nucleotides - set("ACGTN-"))
+                        f"Unknown DNA base(s): {', '.join(nucleotides - set('ACGTN-'))}"
                     )
 
         return sequence
@@ -1984,10 +1939,10 @@ class Reads:
     def temporalBaseCounts(
         self,
         firstPostId: str,
-        minFrequency: Optional[float] = None,
-        maxFrequency: Optional[float] = None,
+        minFrequency: float | None = None,
+        maxFrequency: float | None = None,
         minCount: int = 0,
-        preIds: Optional[Set[str]] = None,
+        preIds: set[str] | None = None,
     ):
         """
         Iterate through time-sorted reads, accumulating counts of bases at each
@@ -2290,7 +2245,7 @@ class ReadsInRAM(Reads):
     # inheritance. If you want a real list, you can just call C{list} on a
     # C{Reads} or C{ReadsInRAM} instance.
 
-    def __init__(self, initialReads: Optional[Iterable[Read]] = None):
+    def __init__(self, initialReads: Iterable[Read] | None = None):
         super().__init__(initialReads)
 
         # Read all initial reads into memory.
@@ -2305,13 +2260,13 @@ class ReadsInRAM(Reads):
     def __len__(self) -> int:
         return self._additionalReads.__len__()
 
-    def __getitem__(self, item: SupportsIndex) -> Union[Read, Reads]:
+    def __getitem__(self, item: SupportsIndex) -> Read | Reads:
         return self._additionalReads.__getitem__(item)
 
     def __setitem__(self, item: SupportsIndex, value: Read) -> None:
         return self._additionalReads.__setitem__(item, value)
 
-    def __iter__(self) -> Generator[Read, None, None]:
+    def __iter__(self) -> Iterator[Read]:
         for read in self._additionalReads.__iter__():
             yield read
 
@@ -2325,12 +2280,11 @@ def addFASTACommandLineOptions(parser: argparse.ArgumentParser) -> None:
 
     parser.add_argument(
         "--fastaFile",
-        type=open,
-        default=sys.stdin,
+        type=argparse.FileType('rb', 0),
         metavar="FILENAME",
         help=(
             "The name of the FASTA input file. Standard input will be read "
-            "if no file name is given."
+            "if '-' is used or if no file name is given."
         ),
     )
 
@@ -2340,8 +2294,8 @@ def addFASTACommandLineOptions(parser: argparse.ArgumentParser) -> None:
         choices=readClassNameToClass,
         metavar="CLASSNAME",
         help=(
-            "If specified, give the type of the reads in the input. "
-            "Possible choices: %s." % ", ".join(readClassNameToClass)
+            f"If specified, give the type of the reads in the input. "
+            f"Possible choices: {', '.join(readClassNameToClass)}."
         ),
     )
 
@@ -2402,7 +2356,7 @@ def parseFASTACommandLineOptions(args: argparse.Namespace) -> Reads:
 
 
 def getNoCoverageCounts(
-    reads: Iterable[Read], noCoverageChars: Optional[str]
+    reads: Iterable[Read], noCoverageChars: str | None
 ) -> dict[str, int]:
     """
     Get the no-coverage character counts for all reads.
